#ifndef TILDA_WINDOW_H
#define TILDA_WINDOW_H

/*
Object Creation Order
========================================
tilda_window_class_init()
tilda_window_constructor() BEGINS
	tilda_window_instance_init()
	tilda_window_set_property() FOR EACH CTOR PROPERTY USED
tilda_window_constructor() COMPLETES

... usage ...

g_object_unref(...)
tilda_window_dispose()
tilda_window_finalize()
*/

#include <glib.h>
#include <gtk/gtk.h>

#include "tilda-terminal.h"

#define TILDA_TYPE_WINDOW				(tilda_window_get_type())
#define TILDA_WINDOW(obj)				(G_TYPE_CHECK_INSTANCE_CAST ((obj), TILDA_TYPE_WINDOW, TildaWindow))
#define TILDA_WINDOW_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST ((klass), TILDA_TYPE_WINDOW, TildaWindowClass))
#define TILDA_IS_WINDOW(obj)			(G_TYPE_CHECK_INSTANCE_TYPE ((obj), TILDA_TYPE_WINDOW))
#define TILDA_IS_WINDOW_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), TILDA_TYPE_WINDOW))
#define TILDA_WINDOW_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS ((obj), TILDA_TYPE_WINDOW, TildaWindowClass))

typedef struct _TildaWindow TildaWindow;
typedef struct _TildaWindowClass TildaWindowClass;

struct _TildaWindow {
	GObject parent;
	gboolean dispose_has_run;

	/* Instance Members */
	GtkWidget *window;
	GtkWidget *notebook;
	GPtrArray *terms;

	gint number;

	gboolean have_real_transparency;
};

struct _TildaWindowClass {
	GObjectClass parent;

	/* class members */
};

/* used by TILDA_TYPE_WINDOW */
GType tilda_window_get_type (void);

/* API */
gboolean tilda_window_remove_term (TildaWindow *tw, gint terminal_number);

#endif /* TILDA_WINDOW_H */

/* vim: set ts=4 sts=4 sw=4 noet tw=112: */

